@@ -31,55 +31,53 @@ TwitterButton::TwitterButton(ButtonType buttonType, QString buttonLabel, QGraphi
         _buttonLabel(buttonLabel)
 {
     _pen.setColor(QColor(15, 149, 218));
-    setTypeButton(buttonType);
     _buttonType = buttonType;
-
-
-}
-
-/*! \brief TwitterButton constructor.
- *  \param buttonType
- *  \param buttonLabel String to be written on the button.
- *  \param response the url
- */
-TwitterButton::TwitterButton(ButtonType buttonType, QString buttonLabel, QString response, QGraphicsWidget *parent)
-        : TwitterApplicationItem(parent),
-        _buttonLabel(buttonLabel)
-{
-    _pen.setColor(QColor(15, 149, 218));
-    _buttonType = buttonType;
-    _response = response;
+    m_isPressed = false;
 
     setTypeButton(buttonType);
-
-}
-
-/*!
- * \brief TwitterButton destructor.
- */
-TwitterButton::~TwitterButton()
-{
 }
 
 /*!
  * \brief Overridden.
  */
-void TwitterButton::mousePressEvent(QGraphicsSceneMouseEvent *)
+void TwitterButton::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
+    if(contains(event->pos())) {
+        m_isPressed = true;
+        emit pressed();
+    }
+
     update();
-    emit pressed();
 }
 
 /*!
  * \brief Overridden.
  */
-void TwitterButton::mouseReleaseEvent(QGraphicsSceneMouseEvent *)
+void TwitterButton::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
+    if(!contains(event->pos()))
+        return;
+
+    m_isPressed = false;
     update();
-    if(_response.isNull() || _response.isEmpty())
+
+    if(_url.isEmpty())
         emit released();
     else
-        emit released(_response);
+        emit released(_url);
+}
+
+/*!
+ * \brief Overridden.
+ */
+void TwitterButton::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
+{
+    if(contains(event->pos()))
+        m_isPressed = true;
+    else
+        m_isPressed = false;
+
+    update();
 }
 
 /*!
@@ -111,7 +109,7 @@ void TwitterButton::paint(QPainter *painter, const QStyleOptionGraphicsItem *opt
 {
     bool down = option->state & QStyle::State_Sunken;
 
-    if (down) {
+    if (down && m_isPressed) {
         painter->translate(2, 2);
         painter->setOpacity(0.7);
 
@@ -119,9 +117,6 @@ void TwitterButton::paint(QPainter *painter, const QStyleOptionGraphicsItem *opt
             case Update:
                 _buttonSelectedImage = QPixmap(":images/resources/buttons/update_pressed.png");
                 break;
-            case Refresh:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/refresh_pressed.png");
-                break;
             case Expose:
                 _buttonSelectedImage = QPixmap(":images/resources/buttons/expose_pressed.png");
                 break;
@@ -148,22 +143,18 @@ void TwitterButton::paint(QPainter *painter, const QStyleOptionGraphicsItem *opt
                 break;
             case Favorite:
                 _buttonSelectedImage = QPixmap(":images/resources/buttons/favorite_pressed.png");
-                _buttonImage = QPixmap(":images/resources/buttons/no-fave.png");
-                _buttonType = TwitterButton::NoFavorite;
                 break;
             case NoFavorite:
                 _buttonSelectedImage = QPixmap(":images/resources/buttons/no-fave_pressed.png");
-                _buttonImage = QPixmap(":images/resources/buttons/favorite.png");
-                _buttonType = TwitterButton::Favorite;
                 break;
             case More:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/more_pressed.png");
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/more-pressed.png");
                 break;
         }
 
-    } else {
+    } else
         _buttonSelectedImage = 0;
-    }
+
     painter->drawPixmap(0, 0, _buttonImage);
     painter->setOpacity(1.0);
     painter->drawPixmap(0, 0, _buttonSelectedImage);
@@ -188,20 +179,10 @@ void TwitterButton::paint(QPainter *painter, const QStyleOptionGraphicsItem *opt
  */
 void TwitterButton::enable(bool option)
 {
-    if(!option) {
-        switch(_buttonType) {
-            case Update:
-                _pen.setColor(QColor(117, 117, 117));
-                break;
-        }
-    }
-    else {
-        switch(_buttonType) {
-            case Update:
-                _pen.setColor(QColor(15, 149, 218));
-                break;
-        }
-    }
+    if(!option)
+        _pen.setColor(QColor(117, 117, 117));
+    else
+        _pen.setColor(QColor(15, 149, 218));
     this->setEnabled(option);
 }
 
@@ -211,14 +192,10 @@ void TwitterButton::enable(bool option)
  */
 void TwitterButton::setTypeButton(int buttonType)
 {
-
     switch(buttonType){
         case Update:
             _buttonImage = QPixmap(":images/resources/buttons/update.png");
             break;
-        case Refresh:
-            _buttonImage = QPixmap(":images/resources/buttons/refresh.png");
-            break;
         case Expose:
             _buttonImage = QPixmap(":images/resources/buttons/expose.png");
             break;
@@ -249,15 +226,15 @@ void TwitterButton::setTypeButton(int buttonType)
         case Back:
             _buttonImage = QPixmap(":images/resources/buttons/back.png");
             break;
+        case Tab:
+            _buttonImage = QPixmap(":images/resources/buttons/tab.png");
+            break;
         case More:
             _buttonImage = QPixmap(":images/resources/buttons/more.png");
             break;
-
     }
-
-    setCacheMode(DeviceCoordinateCache);
-    setGeometry(_buttonImage.rect());
-
+    this->_buttonType = buttonType;
+    update();
 }
 
 /*!
@@ -268,3 +245,12 @@ void TwitterButton::setLabel(QString label)
 {
     this->_buttonLabel = label;
 }
+
+/*!
+ * \brief This function sets the url in the button.
+ * \param response The button's url.
+ */
+void TwitterButton::setUrl(QString url)
+{
+    this->_url = url;
+}
